@@ -3,10 +3,10 @@
 Created on Mon Dec 20 13:19:38 2021
 @author: ninad
 """
-from resource import Rotors
-from resource import cipher
-from resource import generate
-from resource import convert
+import Rotors
+import cipher
+import generate
+import convert
 
 class EnigmaOP:
     
